@@ -1655,7 +1655,7 @@ def get_holiday_from_gov(year):
 
     return holiday_date_list, half_day_mkt_date_list
 
-def get_hk_holiday_and_expiry_date(start_year, end_year, format='int'):
+def get_hk_holiday_and_expiry_date(start_year, end_year, format='int', str_format = '%Y%m%d'):
     holiday_date_list = []
     half_day_mkt_date_list = []
 
@@ -1682,7 +1682,7 @@ def get_hk_holiday_and_expiry_date(start_year, end_year, format='int'):
                     trading_days += 1
                 if trading_days == 2:
                     if format == 'str' or format == 'string':
-                        expiry_date = test_date.strftime('%Y%m%d')
+                        expiry_date = test_date.strftime(str_format)
                     elif format == 'int' or format == 'integer':
                         expiry_date = int(test_date.strftime('%Y%m%d'))
                     elif format == 'dt' or format == 'datetime':
@@ -1693,7 +1693,7 @@ def get_hk_holiday_and_expiry_date(start_year, end_year, format='int'):
     holiday_list = []
     for day in holiday_date_list:
         if format == 'str' or format == 'string':
-            holiday = day.strftime('%Y%m%d')
+            holiday = day.strftime(str_format)
         elif format == 'int' or format == 'integer':
             holiday = int(day.strftime('%Y%m%d'))
         elif format == 'dt' or format == 'datetime':
@@ -1703,7 +1703,7 @@ def get_hk_holiday_and_expiry_date(start_year, end_year, format='int'):
     half_day_mkt_list = []
     for day in half_day_mkt_date_list:
         if format == 'str' or format == 'string':
-            holiday = day.strftime('%Y%m%d')
+            holiday = day.strftime(str_format)
         elif format == 'int' or format == 'integer':
             holiday = int(day.strftime('%Y%m%d'))
         elif format == 'dt' or format == 'datetime':
